@@ -6,7 +6,7 @@ require     Tk::Canvas;
 use strict;use warnings;use utf8;
 use         Tk;
 use         Carp;
-our $VERSION     = '1.10';my $d8VS='H7DMAlTk';
+our $VERSION     = '1.12';my $d8VS='H7DMAlTk';
 @Tk::AbstractCanvas::ISA = qw(Tk::Derived Tk::Canvas); Construct Tk::Widget 'AbstractCanvas';
 sub Tk::Widget::ScrlACnv { shift->Scrolled('AbstractCanvas'=>@_) }
 my %_can_rotate_about_center = ( # If objects can't rotate about their center, their center can at least rotate about another point on the canvas.
@@ -604,7 +604,7 @@ Tk::AbstractCanvas - Canvas with Abstract center, zoom, and rotate methods
 
 =head1 VERSION
 
-This documentation refers to version 1.10 of Tk::AbstractCanvas, which was released on
+This documentation refers to version 1.12 of Tk::AbstractCanvas, which was released on
 Thu Jul 13 10:47:29:46 -0500 2017.
 
 =head1 SYNOPSIS
@@ -970,9 +970,11 @@ Revision history for Perl extension Tk::AbstractCanvas:
 
 =over 2
 
-=item - 1.10 H7DMAlTk Thu Jul 13 10:47:29:46 -0500 2017
+=item - 1.12 H7DMAlTk Thu Jul 13 10:47:29:46 -0500 2017
 
-* added Tk to required in Makefile && METAs, and put eval use Tk in 01podc.t to hopefully resolve newest CPANTesters failure on make test
+* skipped over VERSION 1.10 since it is the same as 1.1, but maybe would work if I had started with 'v' or 1.01 instead
+
+* added Tk to required in Makefile and METAs, and put eval use Tk in 01podc.t to hopefully resolve newest CPANTesters failure on make test
 
 * removed duplicate description heading from POD
 
